@@ -177,12 +177,15 @@ class AB_Base:
                 self.logger.debug("Error Message: {}".format(error))
             else:
                 if data_request.status_code != requests.codes.ok:
+                    self.logger.error("Unable to Search {} for Data".format(self.name))
                     self.logger.debug(data_request.text)
                     raise ValueError()
                 else:
                     self.kwargs["all_data"] = data_request.json()
 
         found_item = None
+        self.logger.debug("All JQ: {}".format(self.all_jq))
+        self.logger.debug(self.kwargs["all_data"])
         for potential in pyjq.all(self.all_jq, self.kwargs["all_data"]):
             if self.kwargs.get("uid", None) is not None:
                 if potential.get(self.uid_field, None) == self.kwargs["uid"]:
